//genesis
// This simulation generates figures 2A and 2C.
include fb28a.g

float fastdt = 1e-5
float normdt = 1e-3
float plotdt = 60 	// Plot clock set to plot one point per minute

function do_run(conc)
	float conc

	setclock 3 10000	// disable plots till initial settling is over
	setfield /kinetics/PDGFR/PDGF CoInit 0
	reset
	// Let the model settle down
	setclock 0 {fastdt}
	setclock 1 {fastdt}
	step 2 -t
	setclock 0 {normdt}
	setclock 1 {normdt}
	step 9998 -t

	// Apply the PDGF for 5 min
	setfield /kinetics/PDGFR/PDGF CoInit {conc}

	setclock 3 {plotdt} // enable the plots
	setclock 0 {fastdt}
	setclock 1 {fastdt}
	step 2 -t
	setclock 0 {normdt}
	setclock 1 {normdt}
	step 298 -t

	// Turn off PDGF, wait for 30 min
	setfield /kinetics/PDGFR/PDGF CoInit 0

	setclock 0 {fastdt}
	setclock 1 {fastdt}
	step 2 -t
	setclock 0 {normdt}
	setclock 1 {normdt}
	step {120 * 60 - 2} -t
end

function scale_all_enz_Vmax(pool, factor)
	str pool
	float factor

	str enz
	float temp
	foreach enz ({el {pool}/##[][TYPE=kenz]})
		temp = {getfield {enz} k3}
		setfield {enz} k3 {temp * factor}
		temp = {getfield {enz} k2}
		setfield {enz} k2 {temp * factor}
		temp = {getfield {enz} k1}
		setfield {enz} k1 {temp * factor}
	end
end



// 1 ng/ml = 3e-14 mole/1e-3 l = 3e-11 M = 0.03 nM.
do_run 1.5e-3
do_save_named_plot /graphs/conc1/MAPK*.Co control.plot

// Inhibit PKC by reducing the activity of its enzymes to 20%
scale_all_enz_Vmax /kinetics/PKC-active 0.2
do_run 1.5e-3
do_save_named_plot /graphs/conc1/MAPK*.Co fig2c_pkc_block.plot
scale_all_enz_Vmax /kinetics/PKC-active 5 // restore activity

// Inhibit PKC by downregulation
setfield /kinetics/PKC/PKC-cytosolic CoInit 0.2
do_run 1.5e-3
do_save_named_plot /graphs/conc1/MAPK*.Co pkc_downreg.plot
setfield /kinetics/PKC/PKC-cytosolic CoInit 1 // restore PKC levels

// Inhibit PLA2 by reducing activity to 20%
scale_all_enz_Vmax /kinetics/PLA2 0.2
do_run 1.5e-3
do_save_named_plot /graphs/conc1/MAPK*.Co fig2a_pla2_block.plot
scale_all_enz_Vmax /kinetics/PLA2 5 // restore activity

// Inhibit MAPK by overexpressing MKP-1.
setfield /kinetics/MKP-1 CoInit 0.002 slave_enable 4
do_run 1.5e-3
do_save_named_plot /graphs/conc1/MAPK*.Co MKP1_overexpress.plot
setfield /kinetics/MKP-1 CoInit 0.0004 slave_enable 0

quit
