//genesis
// This simulation complements figures 2A and 2C. In those printed
// figures, the stimulus strength was set so as to ensure that the
// basal activation of MAPK, due to Raf and Raf* respectively, were
// similar. In those simulations the MAPK response amplitude was 
// much smaller when feedback was blocked, since the PKC activity was
// low and there was little Raf*. 
// In the simulations in this file we show that even when the MAPK
// response is comparable, the duration of MAPK response is brief
// when the feedback loop is blocked. In order to make the MAPK
// response amplitude comparable even when PKC is blocked, we
// transiently alter rate constants for Raf stimulation during
// the stimulus, and then restore then to their basal levels
// to monitor the response.

include fb28a.g

float fastdt = 1e-5
float normdt = 1e-3
float plotdt = 60 	// Plot clock set to plot one point per minute

function do_run(conc)
	float conc


	setclock 3 10000	// disable plots till initial settling is over
	setfield /kinetics/PDGFR/PDGF CoInit 0
	reset
	// Let the model settle down
	setclock 0 {fastdt}
	setclock 1 {fastdt}
	step 2 -t
	setclock 0 {normdt}
	setclock 1 {normdt}
	step 9998 -t

	// Apply the PDGF, raise the RGR stim for 5 min
	setfield /kinetics/PDGFR/PDGF CoInit {conc}
	setfield /kinetics/Ras-act-unphosph-raf kf 1e-4 kb 0.5
	setfield /kinetics/Ras/Ras-intrinsic-GTPase kb 0.001

	setclock 3 {plotdt} // enable the plots
	setclock 0 {fastdt}
	setclock 1 {fastdt}
	step 2 -t
	setclock 0 {normdt}
	setclock 1 {normdt}
	step 298 -t

	// Turn off PDGF, restore the RGR stim, wait for 30 min
	setfield /kinetics/PDGFR/PDGF CoInit 0
	setfield /kinetics/Ras-act-unphosph-raf kf 1e-5 kb 1
	setfield /kinetics/Ras/Ras-intrinsic-GTPase kb 0

	setclock 0 {fastdt}
	setclock 1 {fastdt}
	step 2 -t
	setclock 0 {normdt}
	setclock 1 {normdt}
	step {120 * 60 - 2} -t
end

function scale_all_enz_Vmax(pool, factor)
	str pool
	float factor

	str enz
	float temp
	foreach enz ({el {pool}/##[][TYPE=kenz]})
		temp = {getfield {enz} k3}
		setfield {enz} k3 {temp * factor}
		temp = {getfield {enz} k2}
		setfield {enz} k2 {temp * factor}
		temp = {getfield {enz} k1}
		setfield {enz} k1 {temp * factor}
	end
end



// 1 ng/ml = 3e-14 mole/1e-3 l = 3e-11 M = 0.03 nM.
do_run 1.5e-3
do_save_named_plot /graphs/conc1/MAPK*.Co fig2ac_supplement.control.plot

// Inhibit PKC by reducing the activity of its enzymes to 20%
scale_all_enz_Vmax /kinetics/PKC-active 0.2
do_run 1.5e-3
do_save_named_plot /graphs/conc1/MAPK*.Co fig2c_supplement_pkc_block.plot
scale_all_enz_Vmax /kinetics/PKC-active 5 // restore activity

// Inhibit PKC by downregulation
setfield /kinetics/PKC/PKC-cytosolic CoInit 0.2
do_run 1.5e-3
do_save_named_plot /graphs/conc1/MAPK*.Co supplement_pkc_downreg.plot
setfield /kinetics/PKC/PKC-cytosolic CoInit 1 // restore PKC levels

// Inhibit PLA2 by reducing activity to 20%
scale_all_enz_Vmax /kinetics/PLA2 0.2
do_run 1.5e-3
do_save_named_plot /graphs/conc1/MAPK*.Co fig2a_supplement_pla2_block.plot
scale_all_enz_Vmax /kinetics/PLA2 5 // restore activity

// Inhibit MAPK by overexpressing MKP-1.
setfield /kinetics/MKP-1 CoInit 0.002 slave_enable 4
do_run 1.5e-3
do_save_named_plot /graphs/conc1/MAPK*.Co supplement_MKP1_overexpress.plot
setfield /kinetics/MKP-1 CoInit 0.0004 slave_enable 0 // restore MKP1

quit
