//genesis
// This simulation generates the intersecting conc-effect curves
// for PLA2 and MAPK as in fig 3c.
// fb31.g differs from the reference model in lacking steps for the
// turnover of MKP-1.
// This simulation differs from fig1c only in assigning a higher
// level of MKP-2.

include fb31.g
setfield /kinetics/MKP-2 CoInit 0.012


// Define clocks.
float fastclock = 0.0001
float normclock = 0.005
float equilclock = 0.005
float fastequil = 2
float equiltime = 4000
float normtime = 2500

// define output file
str fn = "fig3c"


function do_output
	echo {getfield /kinetics/MAPK*  Co} \
		{getfield /kinetics/AA Co} >> {fn}.AvsM
end

function do_stim(level,runtime)
	float level,runtime

	//date
	echo doing {runtime} sec at level= {level}
	setclock 0 {fastclock}
	setclock 1 {fastclock}
	step {fastequil} -t
	setclock 0 {normclock}
	setclock 1 {normclock}
	step {runtime - fastequil} -t
	do_output
end

function do_MAPK_dose_response
	reset
	float MAPK = 1e-6
	
	float tc = normclock
	normclock = equilclock

	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {equiltime}
	
	normclock = tc

	MAPK = 0.001
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}

	MAPK = MAPK + 0.001
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}

	MAPK = MAPK + 0.002
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}

	MAPK = MAPK + 0.002
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}
	
	MAPK = MAPK + 0.004
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}
	
	MAPK = MAPK + 0.01
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}
	
	MAPK = MAPK + 0.02
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}
	
	MAPK = MAPK + 0.04
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}
	
	MAPK = MAPK + 0.04
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}
	
	MAPK = MAPK + 0.08
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}

	MAPK = MAPK + 0.8
	setfield /kinetics/MAPK* slave_enable 4 CoInit {MAPK}
	do_stim {MAPK} {normtime}

	setfield /kinetics/MAPK* slave_enable 0 CoInit 0
end


function do_AA_dose_response
	reset
	float AA = 1e-6

	float tc = normclock
	normclock = equilclock
	setfield /kinetics/AA slave_enable 4 CoInit {AA}
	do_stim {AA} {equiltime}
	
	normclock = tc

	AA = 5
	setfield /kinetics/AA slave_enable 4 CoInit {AA}
	do_stim {AA} {normtime}
	
	AA = AA + 5
	setfield /kinetics/AA slave_enable 4 CoInit {AA}
	do_stim {AA} {normtime}
	
	AA = AA + 5
	setfield /kinetics/AA slave_enable 4 CoInit {AA}
	do_stim {AA} {normtime}
	
	AA = AA + 5
	setfield /kinetics/AA slave_enable 4 CoInit {AA}
	do_stim {AA} {normtime}
	
	AA = AA + 10
	setfield /kinetics/AA slave_enable 4 CoInit {AA}
	do_stim {AA} {normtime}
	
	AA = AA + 15
	setfield /kinetics/AA slave_enable 4 CoInit {AA}
	do_stim {AA} {normtime}
	
	AA = AA + 20
	setfield /kinetics/AA slave_enable 4 CoInit {AA}
	do_stim {AA} {normtime}

	setfield /kinetics/AA slave_enable 0 CoInit 0
end

	// Set up the xplot
	echo " " >> {fn}.AvsM
	echo "/xtitle MAPK" >> {fn}.AvsM
	echo "/ytitle AA" >> {fn}.AvsM

	// First the original curve for varying AA
	echo >> {fn}.AvsM
	echo "/newplot" >> {fn}.AvsM
	echo "/plotname varyAA" >> {fn}.AvsM
	echo "varying AA "
	do_AA_dose_response

	// then the original curve for varying MAPK
	echo >> {fn}.AvsM
	echo "/newplot" >> {fn}.AvsM
	echo "/plotname varyMAPK" >> {fn}.AvsM
	echo "varying MAPK"
	do_MAPK_dose_response

quit
